package Bundle::Compress;

use 5.008008;
use strict;
use warnings;

our $VERSION = '0.03';



1;
__END__


=head1 NAME

Bundle::Compress - installs Compress modules

=head1 SYNOPSIS

  cpan Bundle::Compress

=head1 CONTENTS

XSLoader

AutoLoader

Data::Dumper

Test::Simple

Test::Harness

Test::Exception

Test::Warn

Test::Manifest

IO

IO::Compress::Base

IO::Compress::Base::Common

IO::Uncompress::Base

IO::Compress::Gzip

IO::Compress::Gzip::Constants

IO::Uncompress::Gunzip

Compress::Zlib

IO::Zlib

Compress::Bzip2

Compress::LZW::Progressive

Compress::unLZMA

Compress::AsciiFlate

Compress::LZO

Compress::LZW

Compress::LZF

Compress::Zlib::Perl

Compress::Raw::Bzip2

Compress::PPMd

Compress::SelfExtracting

Compress::LeadingBlankSpaces

Compress::BraceExpansion

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
